# package version list

List all package versions in the Dev Hub org.

## Description for package version list

Description

## Aliases for package version list

`force:package:version:list`

## Flags

| Flag Name (Long)          | Flag Name (Short) | Description                                                                                                                                              |
| ------------------------- | ----------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------- |
| `--api-version`           | N/A               | **Type:** Value<br><br>Override the api version used for api requests made by this command                                                               |
| `--branch`                | `-b`              | **Type:** Value<br><br>Branch in your source control system used to filter the results; only package versions based on the specified branch are listed.  |
| `--concise`               | N/A               | **Type:** Boolean<br><br>Display limited package version details.                                                                                        |
| `--created-last-days`     | `-c`              | **Type:** Value<br><br>Number of days since the request was created, starting at 00:00:00 of first day to now. Use 0 for today.                          |
| `--flags-dir`             | N/A               | **Type:** Value<br><br>Import flag values from a directory.                                                                                              |
| `--json`                  | N/A               | **Type:** Boolean<br><br>Format output as json.                                                                                                          |
| `--modified-last-days`    | `-m`              | **Type:** Value<br><br>Number of days since the items were modified, starting at 00:00:00 of first day to now. Use 0 for today.                          |
| `--order-by`              | `-o`              | **Type:** Value<br><br>Package version fields used to order the list.                                                                                    |
| `--packages`              | `-p`              | **Type:** Value<br><br>Comma-delimited list of packages (aliases or 0Ho IDs) to list.                                                                    |
| `--released`              | `-r`              | **Type:** Boolean<br><br>Display released versions only (IsReleased=true).                                                                               |
| `--show-conversions-only` | N/A               | **Type:** Boolean<br><br>Filter the list output to display only converted package version.                                                               |
| `--target-dev-hub`        | `-v`              | **Type:** Value<br>**Required**<br><br>Username or alias of the Dev Hub org. Not required if the `target-dev-hub` configuration variable is already set. |
| `--verbose`               | N/A               | **Type:** Boolean<br><br>Display extended package version details.                                                                                       |

## Examples for package version list

List package versions in your default Dev Hub org that were created in the last 3 days; show only the released versions and order the list using the PatchVersion field. Display extended details about each package version:

```shell
sf package version list --verbose --created-last-days 3 --released --order-by PatchVersion
```

List the released package versions for the two specified packages that were modified today; use the Dev Hub org with username <devhub@example.com>:

```shell
sf package version list --packages 0Ho000000000000,0Ho000000000001 --released --modified-last-days 0 --target-dev-hub devhub@example.com
```

List all released package versions in your default Dev Hub org:

```shell
sf package version list --released
```

List package versions that were modified today in your default Dev Hub org; show limited details about each one:

```shell
sf package version list --concise --modified-last-days 0
```

List package versions that are based on the "featureA" branch in your source control system that were modified today in your default Dev Hub org; show limited details about each one:

```shell
sf package version list --concise --modified-last-days 0 --branch featureA
```

List released package versions that were created in the last 3 days in your default Dev Hub org; show limited details:

```shell
sf package version list --concise --created-last-days 3 --released
```

List released package versions that were modified today for the two packages with specified aliases in your default Dev Hub org:

```shell
sf package version list --packages exp-mgr,exp-mgr-util --released --modified-last-days 0
```
